import java.io.*;

import org.jdesktop.lg3d.sg.*;
import org.jdesktop.lg3d.utils.eventaction.*;
import org.jdesktop.lg3d.utils.layoutmanager.*;
import org.jdesktop.lg3d.utils.shape.*;
import org.jdesktop.lg3d.wg.Component3D;
import org.jdesktop.lg3d.wg.Container3D;
import org.jdesktop.lg3d.wg.Frame3D;

public class PanelsFactory {
    public PanelsFactory() {
        Frame3D frame = new Frame3D();
        Container3D container = new Container3D();
        container.setLayout(new BookshelfLayout(true, 0.0f, 0.01f, 0.085f));

        container.addChild(createFuzzyEdgePanel());
        container.addChild(createGlassyPanel());

        Component3D comp = createImagePanel();
        if (comp != null) {
            container.addChild(comp);
        }

        container.addChild(createBevelEdgePanel());

        new ComponentMover(frame);
        frame.addChild(container);

        frame.setCapabilities();
        frame.setActive(true);
        frame.setVisible(true);

    }

    private Component3D createFuzzyEdgePanel() {
        Appearance app = new SimpleAppearance(1.0f, 0.6f, 0.6f, 1.0f, 
                                              SimpleAppearance.DISABLE_CULLING);
        FuzzyEdgePanel panel = new FuzzyEdgePanel(0.08f, 0.06f, 0.005f, app);

        Component3D comp = new Component3D();
        comp.addChild(panel);

        return comp;
    }

    private Component3D createGlassyPanel() {
        Appearance app = new SimpleAppearance(0.6f, 1.0f, 0.6f, 1.0f, 
                                              SimpleAppearance.DISABLE_CULLING);
        GlassyPanel panel = new GlassyPanel(0.08f, 0.06f, 0.01f, 0.005f, app);

        Component3D comp = new Component3D();
        comp.addChild(panel);

        return comp;
    }

    private Component3D createImagePanel() {
        try {
            ImagePanel panel = new ImagePanel("sample.jpg", 0.08f, 0.06f);

            Component3D comp = new Component3D();
            comp.addChild(panel);
            
            return comp;
        } catch (IOException ex) {
            return null;
        }
    }

    private Component3D createBevelEdgePanel() {
        Appearance app = new SimpleAppearance(0.6f, 0.6f, 1.0f, 1.0f, 
                                              SimpleAppearance.DISABLE_CULLING);
        BevelEdgePanel panel = new BevelEdgePanel(0.08f, 0.06f, 0.01f, app);

        Component3D comp = new Component3D();
        comp.addChild(panel);

        return comp;
    }

    public static void main(String[] args) {
        new PanelsFactory();
    }
}
