import java.io.*;

import org.jdesktop.lg3d.sg.*;
import org.jdesktop.lg3d.utils.eventaction.*;
import org.jdesktop.lg3d.utils.layoutmanager.*;
import org.jdesktop.lg3d.utils.shape.*;
import org.jdesktop.lg3d.wg.Component3D;
import org.jdesktop.lg3d.wg.Container3D;
import org.jdesktop.lg3d.wg.Frame3D;

public class ShadowsFactory {
    public ShadowsFactory() {
        Frame3D frame = new Frame3D();
        Container3D container = new Container3D();
        container.setLayout(new BookshelfLayout(true, 0.0f, 0.01f, 0.09f));

        container.addChild(createRectShadow());
        container.addChild(createRoundRingShadow());
        container.addChild(createRoundShadow());

        new ComponentMover(frame);
        frame.addChild(container);

        frame.setCapabilities();
        frame.setActive(true);
        frame.setVisible(true);
    }

    private Component3D createRectShadow() {
        RectShadow shadow = new RectShadow(0.08f, 0.06f, 
                                           0.002f, 0.006f, 0.005f, 0.001f,
                                           0.01f, -0.01f, 1.0f);

        Component3D comp = new Component3D();
        comp.addChild(shadow);

        try {
            ImagePanel panel = new ImagePanel("sample.jpg", 0.08f, 0.06f);
            comp.addChild(panel);
        } catch (IOException ex) {
            ex.printStackTrace();
        }

        return comp;
    }

    private Component3D createRoundRingShadow() {
        RoundRingShadow shadow = new RoundRingShadow(0.06f, 0.04f, 20, 1.0f);

        Component3D comp = new Component3D();
        comp.addChild(shadow);

        return comp;
    }

    private Component3D createRoundShadow() {
        RoundShadow shadow = new RoundShadow(0.08f, 0.08f, 20,
                                             0.01f, 0.02f, 0.04f, 1.0f);

        Component3D comp = new Component3D();
        comp.addChild(shadow);

        return comp;
    }

    public static void main(String[] args) {
        new ShadowsFactory();
    }
}
